@@ -9,8 +9,9 @@ from rich.console import Console
 from rich.table import Table
 from rich.text import Text
 from rich import box
-from .theme import SUCCESS, INFO, ACCENT, PRIMARY
+from ..core.theme import theme
 from .util import LoadingAnimation
+from .error_handling import ValidationError, validate_file_exists, validate_choice, handle_runtime_error
 
 
 # Set to CLI mode
@@ -31,6 +32,7 @@ def filter_bag(
     parallel: bool = typer.Option(False, "--parallel", "-p", help="Process files in parallel when input is a directory"),
     workers: Optional[int] = typer.Option(None, "--workers", help="Number of parallel workers (default: CPU count - 2)"),
     sort_by: str = typer.Option("size", "--sort-by", "-s", help="Sort topics by: topic, count, size (default: size)"),
+    overwrite: bool = typer.Option(True, "--overwrite/--no-overwrite", help="Overwrite existing output files (default: True)"),
     dry_run: bool = typer.Option(False, "--dry-run", help="Show what would be done without actually doing it")
 ):
     """Filter ROS bag files by topics"""
@@ -45,18 +47,13 @@ def filter_bag(
         # Show parser info only when explicitly requested or in debug mode
         logger.debug("Using rosbags parser for enhanced performance and LZ4 support")
         
-        # Validate compression type
-        from roseApp.core.util import validate_compression_type
-        is_valid, error_message = validate_compression_type(compression)
-        if not is_valid:
-            typer.echo(f"Error: {error_message}", err=True)
-            raise typer.Exit(code=1)
-        
-        # Validate sort_by parameter
-        valid_sort_options = ["topic", "count", "size"]
-        if sort_by not in valid_sort_options:
-            typer.echo(f"Error: Invalid sort option '{sort_by}'. Valid options: {', '.join(valid_sort_options)}", err=True)
-            raise typer.Exit(code=1)
+        # Validate parameter values
+        try:
+            validate_file_exists(input_path, "bag file")
+            validate_choice(compression, ["none", "bz2", "lz4"], "--compression")
+            validate_choice(sort_by, ["topic", "count", "size"], "--sort-by")
+        except ValidationError as e:
+            handle_runtime_error(e, "Parameter validation")
         
         # Check if input is a file or directory
         if os.path.isfile(input_path):
@@ -89,7 +86,7 @@ def filter_bag(
                     output_bag = os.path.join(output_dir, os.path.basename(os.path.splitext(input_path)[0]) + "_filtered.bag")
                 
             # Process single file
-            _process_single_bag(parser, input_path, output_bag, whitelist, topics, compression, sort_by, dry_run)
+            _process_single_bag(parser, input_path, output_bag, whitelist, topics, compression, sort_by, overwrite, dry_run)
                 
         else:
             # Directory processing
@@ -112,12 +109,14 @@ def filter_bag(
             os.makedirs(output_dir, exist_ok=True)
                 
             # Process directory
-            _process_directory(parser, input_path, output_dir, whitelist, topics, compression, parallel, workers, sort_by, dry_run)
+            _process_directory(parser, input_path, output_dir, whitelist, topics, compression, parallel, workers, sort_by, overwrite, dry_run)
             
+    except typer.Exit:
+        # Re-raise typer.Exit cleanly
+        raise
     except Exception as e:
-        log_cli_error(e)
-        typer.echo(f"Error: {str(e)}", err=True)
-        raise typer.Exit(code=1)
+        # Handle runtime errors without stack trace
+        handle_runtime_error(e, "Bag filtering operation")
 
 
 def create_responsive_topic_table(all_topics: List[str], connections: Dict[str, str], topic_stats: Dict[str, Dict[str, Any]], 
@@ -165,7 +164,7 @@ def create_responsive_topic_table(all_topics: List[str], connections: Dict[str,
     table.add_column("Topic", justify="left", style="bold", width=topic_width, 
                     overflow="ellipsis", no_wrap=False)
     table.add_column("Count", justify="right", style="cyan", width=count_width)
-    table.add_column("Size", justify="right", style="yellow", width=size_width)
+    table.add_column("Size", justify="right", style=theme.WARNING, width=size_width)
     
     # Calculate summary statistics
     selected_count = 0
@@ -185,7 +184,7 @@ def create_responsive_topic_table(all_topics: List[str], connections: Dict[str,
         total_size += topic_stats.get(topic, {'size': 0})['size']
         
         # Create status icon
-        status_icon = Text("✓", style="green") if is_selected else Text("○", style="yellow")
+        status_icon = Text("✓", style="green") if is_selected else Text("○", style=theme.WARNING)
         
         # Create topic text with appropriate styling and word wrapping
         topic_text = Text(topic, style="green" if is_selected else "white")
@@ -197,7 +196,7 @@ def create_responsive_topic_table(all_topics: List[str], connections: Dict[str,
         
         # Format count and size
         count_text = Text(f"{count:,}", style="cyan")
-        size_text = Text(format_size(size), style="yellow")
+        size_text = Text(format_size(size), style=theme.WARNING)
         
         # Add row to table
         table.add_row(status_icon, topic_text, count_text, size_text)
@@ -247,7 +246,7 @@ def create_test_report_table(test_results: List[Dict[str, Any]], console: Consol
         elif status.lower() in ['fail', 'failed', 'error', 'failed']:
             status_text = Text("✗ FAIL", style="red")
         elif status.lower() in ['skip', 'skipped', 'pending']:
-            status_text = Text("○ SKIP", style="yellow")
+            status_text = Text("○ SKIP", style=theme.WARNING)
         else:
             status_text = Text(status, style="white")
         
@@ -260,9 +259,12 @@ def create_test_report_table(test_results: List[Dict[str, Any]], console: Consol
     return table
 
 
-def _process_single_bag(parser, input_bag: str, output_bag: str, whitelist_file: Optional[str], topics: Optional[List[str]], compression: str, sort_by: str, dry_run: bool):
+def _process_single_bag(parser, input_bag: str, output_bag: str, whitelist_file: Optional[str], topics: Optional[List[str]], compression: str, sort_by: str, overwrite: bool, dry_run: bool):
     """Process a single bag file"""
-    # Get connections info
+    # Get connections info with progress bar
+    from .util import LoadingAnimationWithTimer
+    with LoadingAnimationWithTimer("Loading bag file...", dismiss=True) as progress:
+        progress.add_task(description="Loading...")
     all_topics, connections, _ = parser.load_bag(input_bag)
     
     # Get topic statistics (count and size)
@@ -292,7 +294,7 @@ def _process_single_bag(parser, input_bag: str, output_bag: str, whitelist_file:
                 return f"{size_bytes:.1f}{unit}"
             size_bytes /= 1024
         return f"{size_bytes:.1f}TB"
-    
+        
     # In dry run mode, show what would be done
     if dry_run:
         console = Console()
@@ -357,23 +359,13 @@ def _process_single_bag(parser, input_bag: str, output_bag: str, whitelist_file:
             progress.update(task_id, description=f"Filtering: {display_name}", completed=percent)
         
         # Execute filtering
-        try:
-            result = parser.filter_bag(
-                input_bag, 
-                output_bag, 
-                list(whitelist_topics),
-                progress_callback=update_progress,
-                compression=compression
-            )
-        except FileExistsError:
-            # For CLI command, always overwrite (similar to standard CLI behavior)
             result = parser.filter_bag(
                 input_bag, 
                 output_bag, 
                 list(whitelist_topics),
                 progress_callback=update_progress,
                 compression=compression,
-                overwrite=True
+            overwrite=overwrite
             )
         
         # Update final status
@@ -386,22 +378,39 @@ def _process_single_bag(parser, input_bag: str, output_bag: str, whitelist_file:
     end_time = time.time()
     elapsed = end_time - start_time
     
-    # Calculate size reduction
-    input_size = os.path.getsize(input_bag)
-    output_size = os.path.getsize(output_bag)
-    size_reduction = (1 - output_size/input_size) * 100
+    # Check if no messages were found
+    if "No messages found" in result:
+        typer.secho("\nFiltering failed:", fg=typer.colors.RED, bold=True)
+        typer.echo("─" * 80)
+        typer.echo(f"Time: {int(elapsed//60)} minutes {elapsed%60:.2f} seconds")
+        typer.echo(result)
+        typer.echo("No matching topics found in the bag file.")
+        raise typer.Exit(code=1)
     
-    typer.secho("\nFiltering result:", fg=typer.colors.GREEN, bold=True)
-    typer.echo("─" * 80)
-    typer.echo(f"Time: {int(elapsed//60)} minutes {elapsed%60:.2f} seconds")
-    typer.echo(f"Input size:  {typer.style(f'{input_size/1024/1024:.2f} MB', fg=typer.colors.YELLOW)}")
-    typer.echo(f"Output size: {typer.style(f'{output_size/1024/1024:.2f} MB', fg=typer.colors.YELLOW)}")
-    typer.echo(f"Size reduction:   {typer.style(f'{size_reduction:.1f}%', fg=typer.colors.GREEN)}")
-    typer.echo(result)
+    # Calculate size reduction if output file exists
+    if os.path.exists(output_bag):
+        input_size = os.path.getsize(input_bag)
+        output_size = os.path.getsize(output_bag)
+        size_reduction = (1 - output_size/input_size) * 100
+        
+        typer.secho("\nFiltering result:", fg=typer.colors.GREEN, bold=True)
+        typer.echo("─" * 80)
+        typer.echo(f"Time: {int(elapsed//60)} minutes {elapsed%60:.2f} seconds")
+        typer.echo(f"Input size:  {typer.style(f'{input_size/1024/1024:.2f} MB', fg=typer.colors.YELLOW)}")
+        typer.echo(f"Output size: {typer.style(f'{output_size/1024/1024:.2f} MB', fg=typer.colors.YELLOW)}")
+        typer.echo(f"Size reduction:   {typer.style(f'{size_reduction:.1f}%', fg=typer.colors.GREEN)}")
+        typer.echo(result)
+    else:
+        typer.secho("\nFiltering failed:", fg=typer.colors.RED, bold=True)
+        typer.echo("─" * 80)
+        typer.echo(f"Time: {int(elapsed//60)} minutes {elapsed%60:.2f} seconds")
+        typer.echo(f"Output file was not created: {output_bag}")
+        typer.echo("The filtering process may have failed or been interrupted.")
+        raise typer.Exit(code=1)
 
 
 def _process_directory(parser, input_dir: str, output_dir: str, whitelist_file: Optional[str], topics: Optional[List[str]], 
-                       compression: str, parallel: bool, workers: Optional[int], sort_by: str, dry_run: bool):
+                       compression: str, parallel: bool, workers: Optional[int], sort_by: str, overwrite: bool, dry_run: bool):
     """Process all bag files in a directory"""
     # Get all bag files in the directory (recursive)
     from .util import collect_bag_files
@@ -437,12 +446,12 @@ def _process_directory(parser, input_dir: str, output_dir: str, whitelist_file:
 
     # Process files
     if parallel:
-        _process_directory_parallel(parser, bag_files, input_dir, output_dir, list(whitelist_topics), compression, workers, sort_by)
+        _process_directory_parallel(parser, bag_files, input_dir, output_dir, list(whitelist_topics), compression, workers, sort_by, overwrite)
     else:
-        _process_directory_sequential(parser, bag_files, input_dir, output_dir, list(whitelist_topics), compression, sort_by)
+        _process_directory_sequential(parser, bag_files, input_dir, output_dir, list(whitelist_topics), compression, sort_by, overwrite)
 
 
-def _process_directory_sequential(parser, bag_files: List[str], input_dir: str, output_dir: str, whitelist: List[str], compression: str, sort_by: str):
+def _process_directory_sequential(parser, bag_files: List[str], input_dir: str, output_dir: str, whitelist: List[str], compression: str, sort_by: str, overwrite: bool):
     """Process bag files sequentially"""
     typer.secho(f"\nProcessing {len(bag_files)} bag files sequentially", fg=typer.colors.BLUE, bold=True)
     
@@ -481,23 +490,13 @@ def _process_directory_sequential(parser, bag_files: List[str], input_dir: str,
                     progress.update(task_id, description=f"Filtering: {display_name} ({percent}%)", completed=percent)
                 
                 # Execute filtering
-                try:
-                    result = parser.filter_bag(
-                        bag_file, 
-                        output_path, 
-                        whitelist,
-                        progress_callback=update_progress,
-                        compression=compression
-                    )
-                except FileExistsError:
-                    # For CLI command, always overwrite (similar to standard CLI behavior)
                     result = parser.filter_bag(
                         bag_file, 
                         output_path, 
                         whitelist,
                         progress_callback=update_progress,
                         compression=compression,
-                        overwrite=True
+                    overwrite=overwrite
                     )
                 
                 # Update final status
@@ -522,7 +521,7 @@ def _process_directory_sequential(parser, bag_files: List[str], input_dir: str,
     print_batch_filter_summary(Console(), success_count, fail_count)
 
 
-def _process_directory_parallel(parser, bag_files: List[str], input_dir: str, output_dir: str, whitelist: List[str], compression: str, workers: Optional[int] = None, sort_by: str = "size"):
+def _process_directory_parallel(parser, bag_files: List[str], input_dir: str, output_dir: str, whitelist: List[str], compression: str, workers: Optional[int] = None, sort_by: str = "size", overwrite: bool = True):
     """Process bag files in parallel"""
     import concurrent.futures
     import threading
@@ -587,7 +586,7 @@ def _process_directory_parallel(parser, bag_files: List[str], input_dir: str, ou
                     f"Processing: {display_path}",
                     total=100,
                     completed=0,
-                    style=f"{ACCENT}"
+                    style=f"{theme.ACCENT}"
                 )
                 tasks[bag_file] = task
                 active_files.add(bag_file)
@@ -596,10 +595,10 @@ def _process_directory_parallel(parser, bag_files: List[str], input_dir: str, ou
                 # Create parser instance for this thread if needed
                 if not hasattr(thread_local, 'parser'):
                     # Use RosbagsBagParser for all threads
-                    thread_local.parser = create_parser(ParserType.ROSBAGS)
+                        thread_local.parser = create_parser(ParserType.ROSBAGS)
                 
                 # Initialize progress to 30% to indicate preparation complete
-                progress.update(task, description=f"Processing: {display_path}", style=f"{ACCENT}", completed=30)
+                progress.update(task, description=f"Processing: {display_path}", style=f"{theme.ACCENT}", completed=30)
                 
                 # Define progress update callback function
                 def update_progress(percent: int):
@@ -607,29 +606,17 @@ def _process_directory_parallel(parser, bag_files: List[str], input_dir: str, ou
                     mapped_percent = 30 + (percent * 0.7)
                     progress.update(task, 
                                   description=f"Processing: {display_path} ({percent}%)", 
-                                  style=f"{ACCENT}", 
+                                  style=f"{theme.ACCENT}", 
                                   completed=mapped_percent)
                 
                 # Execute filtering
-                try:
                     thread_local.parser.filter_bag(
                         bag_file, 
                         output_path, 
                         whitelist,
                         progress_callback=update_progress,
                         compression=compression,
-                        overwrite=True  # For parallel processing, always overwrite
-                    )
-                except FileExistsError:
-                    # This should not happen since we use overwrite=True
-                    # but handle it just in case
-                    thread_local.parser.filter_bag(
-                        bag_file, 
-                        output_path, 
-                        whitelist,
-                        progress_callback=update_progress,
-                        compression=compression,
-                        overwrite=True
+                    overwrite=overwrite
                     )
                 
                 # Update task status to complete, showing green success mark
