@@ -139,6 +139,22 @@ class IBagParser(ABC):
         """
         pass
 
+    @abstractmethod
+    def read_messages(self, bag_path: str, topics: List[str]):
+        """
+        Read messages from specified topics in the bag file
+        
+        Args:
+            bag_path: Path to bag file
+            topics: List of topic names to read from
+            
+        Yields:
+            Tuple of (timestamp, message) where:
+            - timestamp: tuple of (seconds, nanoseconds)
+            - message: deserialized ROS message
+        """
+        pass
+
 
 class RosbagsBagParser(IBagParser):
     """High-performance rosbags implementation using AnyReader/Rosbag1Writer"""
@@ -163,21 +179,7 @@ class RosbagsBagParser(IBagParser):
                   progress_callback: Optional[Callable] = None,
                   compression: str = 'none',
                   overwrite: bool = False) -> str:
-        """
-        Filter rosbag using enhanced rosbags AnyReader/Rosbag1Writer
-        
-        Args:
-            input_bag: Path to input bag file
-            output_bag: Path to output bag file  
-            topics: List of topics to include
-            time_range: Optional tuple of ((start_seconds, start_nanos), (end_seconds, end_nanos))
-            progress_callback: Optional callback function to report progress percentage (0-100)
-            compression: Compression type ('none', 'bz2', 'lz4')
-            overwrite: Whether to overwrite existing output file
-        
-        Returns:
-            Status message with completion time
-        """
+        """Filter bag file by topics and time range using AnyReader for performance"""
         try:
             # Validate compression type before starting
             from roseApp.core.util import validate_compression_type
@@ -198,6 +200,10 @@ class RosbagsBagParser(IBagParser):
             # Convert compression format for rosbags
             rosbags_compression = self._get_compression_format(compression)
             
+            # Initialize progress tracking variables
+            last_progress = -1
+            processed_messages = 0
+            
             # Count total messages first for progress tracking
             total_messages = 0
             selected_topic_counts = {}
@@ -272,9 +278,6 @@ class RosbagsBagParser(IBagParser):
                         topic_connections[connection.topic] = new_connection
                     
                     # Process messages with progress tracking
-                    processed_messages = 0
-                    last_progress = -1
-                    
                     # Use efficient message iteration with pre-filtered connections
                     for (connection, timestamp, rawdata) in reader.messages(connections=selected_connections):
                         # Check time range if specified
@@ -299,10 +302,10 @@ class RosbagsBagParser(IBagParser):
             
             if progress_callback and last_progress < 100:
                 progress_callback(100)
-            
+                
             # Log performance statistics
             _logger.info(f"Filtered {processed_messages} messages from {len(selected_connections)} topics in {elapsed:.2f}s")
-            
+                
             return f"Filtering completed in {int(mins)}m {secs:.2f}s"
             
         except ValueError as ve:
@@ -406,7 +409,7 @@ class RosbagsBagParser(IBagParser):
                     topic_counts[connection.topic] = count
                 
                 return topic_counts
-                
+            
         except Exception as e:
             _logger.error(f"Error getting message counts: {e}")
             raise Exception(f"Error getting message counts: {e}")
@@ -431,7 +434,7 @@ class RosbagsBagParser(IBagParser):
         except Exception as e:
             _logger.error(f"Error getting topic sizes: {e}")
             raise Exception(f"Error getting topic sizes: {e}")
-
+    
     def get_topic_stats(self, bag_path: str) -> Dict[str, Dict[str, int]]:
         """Get comprehensive statistics for each topic using AnyReader"""
         try:
@@ -462,6 +465,52 @@ class RosbagsBagParser(IBagParser):
         except Exception as e:
             _logger.error(f"Error getting topic stats: {e}")
             raise Exception(f"Error getting topic stats: {e}")
+    
+    def read_messages(self, bag_path: str, topics: List[str]):
+        """
+        Read messages from specified topics in the bag file
+        
+        Args:
+            bag_path: Path to bag file
+            topics: List of topic names to read from
+            
+        Yields:
+            Tuple of (timestamp, message) where:
+            - timestamp: tuple of (seconds, nanoseconds)
+            - message: deserialized ROS message
+        """
+        try:
+            with AnyReader([Path(bag_path)]) as reader:
+                # Pre-filter connections based on selected topics
+                selected_connections = [
+                    conn for conn in reader.connections 
+                    if conn.topic in topics
+                ]
+                
+                if not selected_connections:
+                    _logger.warning(f"No matching topics found in {bag_path}")
+                    return
+                
+                # Use AnyReader's high-level message iteration with automatic deserialization
+                for (connection, timestamp, rawdata) in reader.messages(connections=selected_connections):
+                    try:
+                        # Use AnyReader's built-in deserialize method
+                        msg = reader.deserialize(rawdata, connection.msgtype)
+                        
+                        # Convert nanosecond timestamp to (seconds, nanoseconds) format
+                        seconds = timestamp // 1_000_000_000
+                        nanoseconds = timestamp % 1_000_000_000
+                        time_tuple = (int(seconds), int(nanoseconds))
+                        
+                        yield (time_tuple, msg)
+                        
+                    except Exception as e:
+                        _logger.warning(f"Could not deserialize message for {connection.topic} ({connection.msgtype}): {e}")
+                        continue
+                
+        except Exception as e:
+            _logger.error(f"Error reading messages from bag with AnyReader: {e}")
+            raise Exception(f"Error reading messages from bag: {e}")
 
 
 def create_parser(parser_type: ParserType = ParserType.ROSBAGS) -> IBagParser:
